@@ -17,7 +17,8 @@ test_that("Anti join works.", {
 })
 
 test_that("Nesting expressions in anti_join's y works.", {
-    expected <- lhs[!lhs[x == "a"], on = "x"]
+    nested <- data.table::copy(lhs)[x == "a"]
+    expected <- lhs[!nested, on = "x"]
     ans <- lhs %>% start_expr %>% anti_join(nest_expr(filter(x == "a")), x) %>% end_expr
     expect_identical(ans, expected)
 })
@@ -33,15 +34,18 @@ test_that("Eager anti_join works.", {
 })
 
 test_that("anti_join can delegate to data.frame method when necessary.", {
-    .expr <- rlang::expr((function() {
-        local_lhs <- data.table::as.data.table(!!lhs)
-        anti_join(data.table::as.data.table(!!rhs), local_lhs, by = c("x", "v"))
-    })())
+    .enclos <- rlang::env(asNamespace("rex"),
+                          lhs = data.table::copy(lhs),
+                          rhs = data.table::copy(rhs))
 
-    expect_warning(ans <- eval(.expr, envir = asNamespace("rex")), "table.express")
+    .fn <- rlang::set_env(new_env = .enclos, function() {
+        anti_join(rhs, lhs, by = c("x", "v"))
+    })
+
+    expect_warning(ans <- .fn(), "table.express")
     expect_equal(ans, dplyr:::anti_join.data.frame(rhs, lhs, by = c("x", "v")))
 
-    .expr <- rlang::expr(anti_join(data.table::as.data.table(!!rhs), data.table::as.data.table(!!lhs), x, v))
+    .expr <- substitute(anti_join(data.table::as.data.table(rhs), data.table::as.data.table(lhs), x, v), .enclos)
     ans_from_workaround <- eval(.expr, envir = asNamespace("rex"))
     expect_equal(ans_from_workaround, anti_join(rhs, lhs, x, v))
 })
